==> store-1.1.1.0.tar.gz: store-1.1.1.0/app/controllers/store/api/store/customers_controller.rb <==
module Store
  module Api
    module Store
      class CustomersController < ::Store::ApplicationController
        before_action :set_customer, only: [:show, :update, :destroy]

        def index
          p = params.to_unsafe_h.except('controller', 'action', 'uuid', 'customer', 'auth_token', 'format', 'sort', 'page')
          search=Search::CustomersSearch.new(p, user: @user).search

          @customers = search.sorter(params[:sort])
          paginate @customers, each_serializer: CustomerSerializer
        end

        def show
          if @customer
            render jsonapi: @customer, serializer: CustomerSerializer
          else
            render_json_error :not_found, :customer_not_found
          end

        end

        def create
          @customer = Customer.new(customer_params)
          @customer.responsible = @user.id
          if @customer.save
            render json: @customer, status: :created #, location: @customer
          else
            respond_with_errors(@customer)
          end
        end

        def update
          if @customer.reload && @customer.writable_by?(@user)
            if @customer.update(customer_params)
              render json: @customer
            else
              respond_with_errors(@customer)
            end
          else
            render_json_error :unprocessable_entity, :not_writers
          end
        end

        def destroy
          if @customer
            if current_user.has_role?("Administrator") || current_user.has_role?("Manager")
              if @customer.destroy
                render body: nil, status: :no_content
              else
                render json: @customer.errors, status: :unprocessable_entity
              end
            else
              render_json_error :not_found, :not_admin_or_manager
            end
          else
            render_json_error :not_found, :customer_not_found
          end
        end

        def current_user
          @user
        end

        def set_customer
          @customer = Customer.readable_by(current_user).find_by(id: params[:id])
        end

        private
        def customer_params
          ActiveModelSerializers::Deserialization.jsonapi_parse!(params, only: [:title, :writers, :readers] )
        end
      end
    end
  end
end

==> store-1.1.3.0.tar.gz: store-1.1.3.0/app/controllers/store/api/store/customers_controller.rb <==
module Store
  module Api
    module Store
      class CustomersController < ::Store::ApplicationController
        before_action :set_customer, only: [:show, :update, :destroy]

        def index
          p = params.to_unsafe_h.except('controller', 'action', 'uuid', 'customer', 'auth_token', 'format', 'sort', 'page')
          search=::Store::Search::CustomersSearch.new(p, user: @user).search

          @customers = search.sorter(params[:sort])
          paginate @customers, each_serializer: CustomerSerializer
        end

        def show
          if @customer
            render jsonapi: @customer, serializer: CustomerSerializer
          else
            render_json_error :not_found, :customer_not_found
          end

        end

        def create
          @customer = Customer.new(customer_params)
          @customer.responsible = @user.id
          if @customer.save
            render json: @customer, status: :created #, location: @customer
          else
            respond_with_errors(@customer)
          end
        end

        def update
          if @customer.reload && @customer.writable_by?(@user)
            if @customer.update(customer_params)
              render json: @customer
            else
              respond_with_errors(@customer)
            end
          else
            render_json_error :unprocessable_entity, :not_writers
          end
        end

        def destroy
          if @customer
            if current_user.has_role?("Administrator") || current_user.has_role?("Manager")
              if @customer.destroy
                render body: nil, status: :no_content
              else
                render json: @customer.errors, status: :unprocessable_entity
              end
            else
              render_json_error :not_found, :not_admin_or_manager
            end
          else
            render_json_error :not_found, :customer_not_found
          end
        end

        def current_user
          @user
        end

        def set_customer
          @customer = Customer.readable_by(current_user).find_by(id: params[:id])
        end

        private
        def customer_params
          ActiveModelSerializers::Deserialization.jsonapi_parse!(params, only: [:title, :writers, :readers] )
        end
      end
    end
  end
end
